// Generated by CoffeeScript 1.8.0
(function() {
  define(['chai', 'backbone', 'backbone-dom-view', 'jquery'], function(_arg, Backbone, DomView, $) {
    var expect, model;
    expect = _arg.expect;
    model = null;
    beforeEach(function() {
      return model = new Backbone.Model();
    });
    return describe('on/once helpers', function() {
      it('should run function on dom event', function() {
        var View, n, view;
        n = 0;
        View = DomView.extend({
          template: {
            '': {
              on: {
                'click': function() {
                  expect(this).to.be.instanceOf(View);
                  return n++;
                }
              }
            }
          }
        });
        view = new View({
          model: model
        });
        view.$el.click();
        expect(n).to.equal(1);
        view.$el.click();
        return expect(n).to.equal(2);
      });
      it('should run function on delegate event', function() {
        var View, eventsCalled, view;
        eventsCalled = 0;
        View = DomView.extend({
          el: '<li><a href="#"></a><button></button></li>',
          template: {
            '': {
              on: {
                'click': {
                  'a': function(e) {
                    eventsCalled++;
                    expect(this).to.be.instanceOf(View);
                    return expect($(e.currentTarget)).to.match('a');
                  },
                  'button': function(e) {
                    eventsCalled++;
                    expect(this).to.be.instanceOf(View);
                    return expect($(e.currentTarget)).to.match('button');
                  }
                }
              }
            }
          }
        });
        view = new View({
          model: model
        });
        view.$el.click();
        view.$el.find('a').click();
        view.$el.find('button').click();
        return expect(eventsCalled).to.be.equal(2);
      });
      it('should run view method if string passed', function() {
        var View, n, view;
        n = 0;
        View = DomView.extend({
          test: function() {
            return n++;
          },
          run: function() {
            return n = 'test';
          },
          template: {
            'root': {
              on: {
                'click': 'test',
                'test': 'run'
              }
            }
          }
        });
        view = new View({
          model: model
        });
        view.$el.click();
        expect(n).to.equal(1);
        view.$el.trigger('test');
        return expect(n).to.equal('test');
      });
      it('should run function once', function() {
        var View, n, view;
        n = 0;
        View = DomView.extend({
          test: function() {
            return n++;
          },
          template: {
            'root': {
              once: {
                'click': 'test'
              }
            }
          }
        });
        view = new View({
          model: model
        });
        view.$el.click();
        expect(n).to.equal(1);
        view.$el.click();
        return expect(n).to.equal(1);
      });
      it('should handle ! as preventDefault', function() {
        var View, n, view;
        n = 0;
        View = DomView.extend({
          test: function() {
            return n++;
          },
          template: {
            'root': {
              on: {
                'click': '!test',
                'test': '!'
              }
            }
          }
        });
        view = new View;
        view.$el.on('click', function(e) {
          n++;
          return expect(e.isDefaultPrevented()).to.equal(true);
        });
        view.$el.on('test', function(e) {
          n = 'test';
          return expect(e.isDefaultPrevented()).to.equal(true);
        });
        view.$el.click();
        expect(n).to.equal(2);
        view.$el.trigger('test');
        return expect(n).to.equal('test');
      });
      return it('should handle click helper', function() {
        var View, n, view;
        n = 0;
        View = DomView.extend({
          test: function() {
            return n++;
          },
          template: {
            'root': {
              click: 'test'
            }
          }
        });
        view = new View;
        view.$el.click();
        return expect(n).to.equal(1);
      });
    });
  });

}).call(this);
